--
-- silage mode on/off
--
-- 06/08/09 guimchevalier from TSF3 www.tsforum3.com 


Ridelles = {};

function Ridelles.prerequisitesPresent(specializations)
    return true
end;


function Ridelles:load(xmlFile)
	-- ON
	-- parts visible when silage is on
	self.on = {};
	
	self.on.count = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.silage.on#count"), 0);
	self.on.capacity = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.silage.on#capacity"), 0);

    for i=1, self.on.count do
        local nodei = string.format("vehicle.silage.on.node%d", i);
		self.on[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, nodei.."#index"));
    end;
	
	-- graincurve when silage is on
	local grainAnimCurve = AnimCurve:new(linearInterpolator4);
	local keyI = 0;
	while true do
		local key = string.format("vehicle.silage.on.key(%d)", keyI);
		local t = getXMLFloat(xmlFile, key.."#time");
		local yValue = getXMLFloat(xmlFile, key.."#y");

		local scaleX,scaleY,scaleZ = Utils.getVectorFromString(getXMLString(xmlFile, key.."#scale"));
		if y == nil or scaleX == nil or scaleY == nil or scaleZ == nil then
			break;
		end;
		grainAnimCurve:addKeyframe({x=scaleX, y=scaleY, z=scaleZ, w=yValue, time = t});
		keyI = keyI +1;
	end;
	if keyI > 0 then
		self.on.grainAnimCurve = grainAnimCurve;
	end;
	
	-- OFF
	-- parts visible when silage is off
	self.off = {};
	
	self.off.count = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.silage.off#count"), 0);
	self.off.capacity = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.silage.off#capacity"), 0);
    for i=1, self.off.count do
        local nodei = string.format("vehicle.silage.off.node%d", i);
		self.off[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, nodei.."#index"));
    end;
	
	-- graincurve when silage is off
	local grainAnimCurve = AnimCurve:new(linearInterpolator4);
	local keyI = 0;
	while true do
		local key = string.format("vehicle.silage.off.key(%d)", keyI);
		local t = getXMLFloat(xmlFile, key.."#time");
		local yValue = getXMLFloat(xmlFile, key.."#y");
		local scaleX,scaleY,scaleZ = Utils.getVectorFromString(getXMLString(xmlFile, key.."#scale"));
		if y == nil or scaleX == nil or scaleY == nil or scaleZ == nil then
			break;
		end;
		grainAnimCurve:addKeyframe({x=scaleX, y=scaleY, z=scaleZ, w=yValue, time = t});
		keyI = keyI +1;
	end;

	if keyI > 0 then
		self.off.grainAnimCurve = grainAnimCurve;
	end;

	-- bquille

	-- KEY
	self.keys = {};
	self.keysName = {};
    local i=0;
    while true do
        local baseName = string.format("vehicle.keys.input(%d)", i);
        local inputName = getXMLString(xmlFile, baseName.. "#name");
        if inputName == nil then
            break;
        end;
        local inputKey = getXMLString(xmlFile, baseName.. "#key");
        if Input[inputKey] == nil then
            print("Error: invalid key '" .. inputKey .. "'  for input event '" .. inputName .. "'");
            break;
        end;
        self.keys[inputName] = Input[inputKey];
		self.keysName[inputName] = Utils.getNoNil(getXMLString(xmlFile, baseName.."#keyname"),"Touche ?");
        i = i+1;
    end;
	
	-- first start
	self.silage = false;
	self.capacity = self.off.capacity;
	self.grainAnimCurve = self.off.grainAnimCurve;
end;

function Ridelles:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	--load function
	local fillLevel = getXMLFloat(xmlFile, key.."#fillLevel");
    local fillType = getXMLString(xmlFile, key.."#fillType");
    self.silage =  Utils.getNoNil(getXMLBool(xmlFile, key.."#silage"),false);
	if self.silage then
		self.capacity = self.on.capacity;
		self.grainAnimCurve = self.on.grainAnimCurve;
	else
		self.capacity = self.off.capacity;
		self.grainAnimCurve = self.off.grainAnimCurve;
	end;
    if fillLevel ~= nil and fillType ~= nil then
        local fillTypeDesc = FruitUtil.fruitTypes[fillType];
        if fillTypeDesc ~= nil then
            self:setFillLevel(fillLevel, fillTypeDesc.index);
        end;
    end;
    return BaseMission.VEHICLE_LOAD_OK;
end;

function Ridelles:getSaveAttributesAndNodes(nodeIdent)
	-- save function
	local silagetext='error';
	if self.silage then
		silagetext='true';
	else
		silagetext='false';
	end;
    local attributes = 'silage="'..silagetext..'"';
   return attributes, nil;
end;

function Ridelles:delete()

end;

function Ridelles:mouseEvent(posX, posY, isDown, isUp, button)

end;

function Ridelles:keyEvent(unicode, sym, modifier, isDown)
	-- on/off
	if self.fillLevel == 0 and sym == self.keys.silage and isDown then
		self.silage = not self.silage;
	end;
end;

function Ridelles:update(dt)
	--capacity grainplane
	if self.fillLevel==0 then
		if self.silage then
			self.capacity = self.on.capacity;
			self.grainAnimCurve = self.on.grainAnimCurve;
		else
			self.capacity = self.off.capacity;
			self.grainAnimCurve = self.off.grainAnimCurve;
		end;
	end;
	-- visibility
	for i=1, self.on.count do
		setVisibility(self.on[i], self.silage);
	end;
	
	for i=1, self.off.count do
		setVisibility(self.off[i], not self.silage);
	end;
end;

function Ridelles:draw()
	if self.fillLevel == 0 then
		if self.silage then
			g_currentMission:addExtraPrintText(string.format("%s : Modalita insilato",self.keysName.silage));
		else
			g_currentMission:addExtraPrintText(string.format("%s : Modalita normale",self.keysName.silage));
		end;
	end;
end;

function Ridelles:onDetach()

end;

function Ridelles:onAttach()

end;
